@@ -70,6 +70,12 @@ api.request = function(method, url, page, callback) {
             if (doc.status == 200) {
                 var data;
                 var contentType = doc.getResponseHeader("Content-Type");
+                var ratelimit = {
+                    "limit": doc.getResponseHeader("x-ratelimit-limit"),
+                    "remaining": doc.getResponseHeader("x-ratelimit-remaining")
+                }
+                if (ratelimit.limit !== "0")
+                    page.updateRateLimit(ratelimit);
                 data = doc.responseText;
                 callback(data,page);
             } else {
@@ -83,6 +89,7 @@ api.request = function(method, url, page, callback) {
     }
 
     doc.open(method, url);
+    doc.setRequestHeader("Accept-Language",api.locale);
     doc.send();
 }
 
@@ -120,6 +127,10 @@ function setPositionSource(source) {
     api.positionSource = source;
 }
 
+function setLocale(locale) {
+    api.locale = locale;
+}
+
 function getLocationParameter() {
     var lat = api.positionSource.position.coordinate.latitude;
     var lon = api.positionSource.position.coordinate.longitude;
